% Program MEDALP
%
% ucitava podatke s Medalpex krstarenja (16-25. ozujak  & 5-16. svibanj 1982.)
% o salinitetu (promil) i temperaturi (deg C) na 43 postaje, na dubinama [0:5:max(h)] m.
% ulazni podaci: medalp_data.mat
%                     ili medalp_asci.dat
% varijable:
%           sal_3, temp_3 - salinitet i temperatura u 3. mjesecu
%           sal_5, temp_5 - salinitet i temperatura u 3. mjesecu
%           dub, cvor       - dubine na kojima su vrsena mjerenja te imena (redni brojevi) postaja
%
% crtanje plana postaja po dubini
% crtanje vertikalnih profila S i T na pojedinim postajama
% preracunavanje dubine u tlak

% zbog jednostavnijeg prikaza, podaci se reduciraju na mrezu (4x10), te
% aproksimiraju pravokutnom, ekvidistantnom mrezom (10 km x 10 km).

% racunanje gustoce u svim mjerenim tockama
% racunanje dinamicke dubine, odn. razlike geopotencijala izmedju povrsine i niza izobarnih ploha

% crtanje horizontalnih presjeka saliniteta, temperature, gustoce, 
% te dinamicke topografije povrsine u odnosu na odabranu izobarnu plohu

% dijelovi programa obuhvaceni s 
%   if(0), end,
% se mogu izvrsavati, ali i ne moraju

% u programu su koristeni ili modificirani gotovi potprogrami
% sw_pres, sw_dens, sw_gpan
% iz "SEAWATER LIBRARY" by Phil Morgan, CSIRO; ftp://ftp.marine.csiro.au/pub/morgan/seawater

% Mira Pasaric (mpasaric@irb.hr)
% 01.12.2004.
% =======================================
% POZIV POTPROGRAMA:
% sub_crtadubine
% sub_vertprofil
% sw_pres
% sw_dens, sw_dens0, sw_seck, sw_smow
% sub_geopot
% sub_2dim
% sub_izolin

% ------------------------------------------- UCITAVANJE PODATAKA u matlab formatu
load medalp_data

data_ascii = 0;
if(data_ascii);                   %   --------------- ucitavanje podataka iz ASCII datoteke
		load medalp_asci.dat
		data = med_mat; clear med_mat;
		dub = data(1,2:end)';
		cvor = data(1+1:1+1+43-1,1)';
		temp_3 = data(1+1:1+1+43-1,2:end)';
		temp_5 = data(1+43+1:1+1+2*43-1,2:end)';
		sal_3 = data(2+2*43+1:2+1+3*43-1,2:end)';
		sal_5 = data(2+3*43+1:2+1+4*43-1,2:end)';
end

% ------------------------------------------- crtanje razdioba podataka po dubinama
crta_dub = 1;
if(crta_dub);
        sub_crtadubine(dub, sal_3, temp_3, sal_5, temp_5, cvor);
end
    
% ------------------------------------------- crtanje vertikalnih profila saliniteta i temperature na pojedinim postajama
if(1)
        slim(1) = min([floor(min(sal_3)) floor(min(sal_5))]), slim(2) = max([ceil(max(sal_3)) ceil(max(sal_5))]);           % apsolutni min i max u polju temperature
        tlim(1) = min([floor(min(temp_3)) floor(min(temp_5))]), tlim(2) = max([ceil(max(temp_3)) ceil(max(temp_5))]);             % apsolutni min i max u polju saliniteta
        kpost = input('Crtanje vertikalnih profila: postaja broj _ ?  (0 za sve postaje) \n');
        
        sub_vertprofil(kpost, dub, sal_3, temp_3, slim, tlim, 3);    
        sub_vertprofil(kpost, dub, sal_5, temp_5, slim, tlim, 5);    
        
end
% ------------------------------------------- PRERACUNAVANJE DUBINA U TLAK
tlak = sw_pres(dub, repmat(44.5,13,1));                     % aproksimacija: geog. sirina = 44.5 N
Tlak = repmat(tlak,1,43);

% redukcija na mrezu 40 postaja; izbacivanje postaja 21, 22, 43

C = cvor; C(43) = []; C(22) = []; C(21) =  []; C = C';              % zadrzavamo pocetna imena postaja
        
s_3 = sal_3; s_3(:,43) = []; s_3(:,22) = []; s_3(:,21) =  [];
s_5 = sal_3; s_5(:,43) = []; s_5(:,22) = []; s_5(:,21) =  [];
t_3 = temp_3; t_3(:,43) = []; t_3(:,22) = []; t_3(:,21) =  [];
t_5 = temp_5; t_5(:,43) = []; t_5(:,22) = []; t_5(:,21) =  [];
Tl = Tlak; Tl(:,43) = []; Tl(:,22) = []; Tl(:,21) =  [];

clear sal* temp* Tlak tlak Lat

% ------------------------------------------- RACUNANJE GUSTOCE I DINAMICKE DUBINE
gustoca_3 = sw_dens(s_3, t_3, Tl);
geopot_3 = sub_geopot(s_3, t_3, Tl);

gustoca_5 = sw_dens(s_5, t_5, Tl);
geopot_5 = sub_geopot(s_5, t_5, Tl);

% ------------------------------------------- preslagivanje polja u pravokutnu, (4 x 10) matricu, za crtanje
Ny = 10; Nx = 4; Nz = length(dub);
X = [0:10:(Nx-1)*10];
Y = [0:10:(Ny-1)*10];

[S3,C2] = sub_2dim(s_3,Ny, Nx, Nz,C);           %   prelaz iz 2-dim (z; postaje) u 3-dim polja (x; y; z)
[T3,C2] = sub_2dim(t_3,Ny, Nx, Nz,C);
[Gust3, C2] = sub_2dim(gustoca_3, Ny, Nx, Nz,C);
[Geop3,C2] = sub_2dim(geopot_3, Ny, Nx, Nz,C);

[S5,C2] = sub_2dim(s_5,Ny, Nx, Nz,C);
[T5,C2] = sub_2dim(t_5,Ny, Nx, Nz,C);
[Gust5, C2] = sub_2dim(gustoca_5, Ny, Nx, Nz,C);
[Geop5,C2] = sub_2dim(geopot_5, Ny, Nx, Nz,C);

% ================= crtanje izolinija
nmesh = 5;              % faktor proguscavanja mreze, zbog izgladjivanja izolinija

ref_dubina = input('Dubina (0 <= d <= 50 m) izobarne plohe koju promatramo  __ ? \n');
Z = find(dub == ref_dubina);

%                                       polja; 3. mjesec

ref = ['0/' num2str(dub(Z))];

sub_izolin (X, Y, Nx, Ny, Z, nmesh, S3, dub, 'Salinitet [^0/_0_0], 3. mjesec');
sub_izolin (X, Y, Nx, Ny, Z, nmesh, T3, dub, 'Tempeartura [^0C], 3. mjesec');
sub_izolin (X, Y, Nx, Ny, Z, nmesh, Gust3, dub, 'Gustoca [kg/m^3], 3. mjesec');
sub_izolin (X, Y, Nx, Ny, Z, nmesh, Geop3, dub, ['Geopotencijal ' ref '  [J/kg], 3. mjesec']);

%                                       polja; 5. mjesec

sub_izolin (X, Y, Nx, Ny, Z, nmesh, S5, dub, 'Salinitet [^0/_0_0], 5. mjesec');
sub_izolin (X, Y, Nx, Ny, Z, nmesh, T5, dub, 'Tempeartura [^0C], 3. mjesec');
sub_izolin (X, Y, Nx, Ny, Z, nmesh, Gust5, dub, 'Gustoca [kg/m^3], 3. mjesec');
sub_izolin (X, Y, Nx, Ny, Z, nmesh, Geop5, dub, ['Geopotencijal ' ref '  [J/kg], 3. mjesec']);
